@@ -1,3 +1,4 @@
+# vim: set ft=perl ts=8 sts=2 sw=2 tw=100 et :
 # no package, so things defined here appear in the namespace of the parent.
 use strictures 2;
 use 5.020;
@@ -31,7 +32,7 @@ my $encoder = JSON::Schema::Modern::_JSON_BACKEND()->new
 
 # like sprintf, but all list items are JSON-encoded. assumes placeholders are %s!
 sub json_sprintf {
-  sprintf(shift, map +(ref($_) =~ /^Math::Big(Int|Float)$/ ? ref($_).'->new(\''.$_.'\')' : $encoder->indent(0)->encode($_)), @_);
+  sprintf(shift, map +(ref($_) =~ /^Math::Big(?:Int|Float)$/ ? ref($_).'->new(\''.$_.'\')' : $encoder->indent(0)->encode($_)), @_);
 }
 
 # deep comparison, with Test::Deep syntax sugar
